@@ -1,6 +1,6 @@
-# This file is part of TMart.
+# This file is part of T-Mart.
 #
-# Copyright 2022 Yulun Wu.
+# Copyright 2023 Yulun Wu.
 #
 # T-Mart is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -8,8 +8,6 @@
 # (at your option) any later version.
 
 
-
-
 # Atmosphere object  
 
 import numpy as np
@@ -19,9 +17,7 @@ from scipy.interpolate import interp1d
 import Py6S
 from Py6S.Params.atmosprofile import AtmosProfile
 from Py6S.Params.aeroprofile import AeroProfile
-
 from .Aerosol import find_aerosolSPF
-
 import os.path
 
 
@@ -32,7 +28,7 @@ class Atmosphere():
 
     * ``atm_profile`` -- AtmosProfile object from Py6S. 
     * ``aot550`` -- AOT at 550nm.
-    * ``aerosol_type`` -- 'BiomassBurning', 'Continental', 'Desert', 'Maritime', 'Stratospheric' or 'Urban', as provided by 6S. 
+    * ``aerosol_type`` -- 'BiomassBurning', 'Continental', 'Desert', 'Maritime', 'Stratospheric' or 'Urban', as provided by 6S. Alternatively, a decimal between 0 and 1 indicating the ratio of 'Maritime' aerosol in a 'Maritime' and 'Continental' mixture. 
     * ``wl`` -- central wavelength in nm.
     * ``n_layers`` -- Number of atmosphere layers to use. Default 20. 
     * ``AEROSOL_SCALE_HEIGHT`` -- Aerosol scale height in km. Default 2km. 
@@ -104,8 +100,15 @@ class Atmosphere():
         layers_ot_mie, layers_ot_aerosol = self._aerosol_wl(band)
 
         # Retrieve aerosol SPF
-        aerosol_SPF = find_aerosolSPF(self.aerosol_type,wl)
-    
+        if isinstance(self.aerosol_type, str):       
+            aerosol_SPF = find_aerosolSPF(self.aerosol_type,wl)
+            
+        else: # Mix maritime and continental aerosols
+            aerosol_SPF_mar = find_aerosolSPF('Maritime',wl)
+            aerosol_SPF_con = find_aerosolSPF('Continental',wl)
+            aerosol_SPF = aerosol_SPF_mar
+            aerosol_SPF['Value'] = aerosol_SPF_mar['Value'] * self.aerosol_type + aerosol_SPF_con['Value'] * (1-self.aerosol_type)
+            
         layers_ot_total_abs = layers_ot_molecule + layers_ot_aerosol
         
         # A data frame of optical thickness 
@@ -121,12 +124,10 @@ class Atmosphere():
         else:
             atm_OT['ot_rayleigh'] = self.specify_ot_rayleigh       
         
-        
         atm_OT['ot_scatt'] = atm_OT.ot_rayleigh + atm_OT.ot_mie
         atm_OT['l_height'] = atm_OT.Alt_top - atm_OT.Alt_bottom
         atm_OT['percentage'] = 0 # used to calculate travelling distance 
         
-        
         if self.no_absorption:
             atm_OT['ot_abs'] = 0
             
@@ -137,8 +138,6 @@ class Atmosphere():
         
         return atm_OT, aerosol_SPF
     
-    
-    
     # Extract the molecular profile at one wavelength 
     # Return two lists: ot_molecule and ot_rayleigh 
     def _atm_profile_wl(self,band): 
@@ -149,7 +148,6 @@ class Atmosphere():
         layers_alts_bottom = self.layers_alts_bottom
         layers_alts_top = self.layers_alts_top
            
-        
         for i_layer in range(len(layers_alts_bottom)):
         
             alt_bottom = 0
@@ -224,12 +222,8 @@ class Atmosphere():
             relative_ray = layers_ot_rayleigh_new/np.sum(layers_ot_rayleigh_new)    
             layers_ot_rayleigh_new = tao_rayleigh * relative_ray
 
-
         return layers_ot_molecule_new, layers_ot_rayleigh_new   
     
-    
-
-
     # Extract aerosol profile at one wavelength 
     # Find the spectral dependence of AOT and then apply it to AOT550
     def _aerosol_wl(self, band):
@@ -258,12 +252,18 @@ class Atmosphere():
                         "BiomassBurning" : 6,
                         "Stratospheric" : 7}
         
+        if isinstance(self.aerosol_type, str):  
+            s.aero_profile = AeroProfile.PredefinedType(aerosol_dict[self.aerosol_type])
+        
+        else: # ADD self-defined aerosol 
+            r_mar = self.aerosol_type
+            r_con = 1 - r_mar
+            s.aero_profile = AeroProfile.User(soot = 0.01*r_con, water = 0.05*r_mar + 0.29*r_con, 
+                                              oceanic = 0.95*r_mar, dust = 0.7*r_con)
         
-        s.aero_profile = AeroProfile.PredefinedType(aerosol_dict[self.aerosol_type])
         s.aot550 = 1
         s.run()
         
-    
         aerosol_EXT_r550 = s.outputs.optical_depth_total.aerosol # ratio, relative to 550
         
         aerosol_EXT = self.aot550 * aerosol_EXT_r550 # total extinction 
@@ -281,14 +281,3 @@ class Atmosphere():
         layers_ot_aerosol = ot_aerosol * conc_normalized # aerosol absorption
   
         return layers_ot_mie, layers_ot_aerosol # scattering and absorption by aerosol, respectively 
-
-
-
-
-
-
-
-
-
-
-
