@@ -1,17 +1,12 @@
-# This file is part of TMart.
+# This file is part of T-Mart.
 #
-# Copyright 2022 Yulun Wu.
+# Copyright 2023 Yulun Wu.
 #
 # T-Mart is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
-
-
-
-
-
 # Replacing tmart_class
 
 # TMart: Topography-adjusted Monte-Carlo Adjacency-effect Radiative Transfer code
@@ -32,7 +27,7 @@ from .Tmart2 import Tmart2
 # Track progress in multiprocessing
 def _track_job(job, update_interval=2):
     while job._number_left > 0:
-        print("Tasks remaining = {0}".format(job._number_left * job._chunksize))
+        print("Jobs remaining = {0}".format(job._number_left * job._chunksize))
         time.sleep(update_interval)
 
 
@@ -75,7 +70,7 @@ class Tmart(Tmart2):
         self.aerosol_SPF_wl = None 
         
         # Wind
-        self.wind_speed = 10 # default 10 m/s
+        self.wind_speed = 3 # default 3 m/s
         self.wind_azi_avg = True # azimuthally averaged cox munk
         self.wind_dir = 0 # default azimuthal, 0 means UPWIND along x-axis
             # AKA the direction where wind comes from 
@@ -91,9 +86,6 @@ class Tmart(Tmart2):
         # In development 
         self.output_flux = False # output irradiance reflectance, direct irradiance and diffuse irradiance on the ground, under development 
         
-        
-             
-        
     def set_geometry(self, sun_dir=[0,0], target_pt_direction=None, sensor_coords=None, pixel=None, target_coords=None):
         '''Set the sun-target-sensor geometry. Only one of ``sensor_coords``, ``pixel`` and ``target_coords`` is needed. 
         
@@ -125,14 +117,10 @@ class Tmart(Tmart2):
 
 
         '''
-        
-        
         n_not_none = (sum(x is not None for x in [sensor_coords,pixel,target_coords]))
         
         if n_not_none != 1: sys.exit('only one of sensor_coords,pixel,target_coords should be provided')
         
-        
-        
         ### Sensor coordinates, take one of the three inputs 
         
         # direct input 
@@ -189,8 +177,7 @@ class Tmart(Tmart2):
         # Sun direction 
         self.sun_dir = sun_dir # [zenith, azimuthal]        
         
-        
-    def set_wind(self,wind_speed=10,wind_azi_avg=True,wind_dir=0): 
+    def set_wind(self,wind_speed=3,wind_azi_avg=True,wind_dir=0): 
         '''Set wind speed and direction. 
         
         Arguments:
@@ -233,7 +220,7 @@ class Tmart(Tmart2):
     def _init_atm(self,band): 
         
         if self.sensor_coords is None: # Edit!!!
-            print ("WARNING: geometry missing, set_geometry before you run")
+            print ("WARNING: geometry missing, use set_geometry before you run")
         else:
             
             # Atmospheric profile and aerosol SPF
@@ -296,9 +283,11 @@ class Tmart(Tmart2):
         
         
         print(f"Number of job(s): {njobs}")
-        print('Wavelength: ' + str(self.wl))
-        print('target_pt_direction: ' + str(self.target_pt_direction))
-        print('sun_dir: ' + str(self.sun_dir))
+        print('Wavelength: ' + str(self.wl) + ' nm')
+        print('Aerosol type: ' + str(self.Atmosphere.aerosol_type))
+        print('AOT at 550 nm: ' + str(self.Atmosphere.aot550)) 
+        print('Photon\'s initial direction: ' + str( np.round(self.target_pt_direction,2) ))
+        print('Solar angle: ' + str( np.round(self.sun_dir, 2) ))
         print("=====================================")
         
 
@@ -353,8 +342,6 @@ class Tmart(Tmart2):
           results = my_tmart.run_plot(wl=wl, plot_on=True, plot_range=[0,100_000,0,100_000,0,100_000])
           
         '''
-        
-        
         print("\n====== Running and Plotting T-Mart Single Photon ======")
         self.wl = wl 
         self.print_on = True    # Always print the details of photon movements 
@@ -363,16 +350,3 @@ class Tmart(Tmart2):
         self._init_atm(band)
         
         return self._run_single_photon(0)
-    
-    
-
-
-
-
-
-
-
-
-
-
-
