@@ -1,6 +1,6 @@
-# This file is part of TMart.
+# This file is part of T-Mart.
 #
-# Copyright 2022 Yulun Wu.
+# Copyright 2023 Yulun Wu.
 #
 # T-Mart is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -9,8 +9,6 @@
 
 
 
-
-
 from .Surface import Surface, SpectralSurface
 from .Atmosphere import Atmosphere
 
@@ -20,6 +18,6 @@ from .tm_calcref import calc_ref
 from .tm_geometry import dirP_to_coord
 
 from tmart import AEC
-
+from tmart import surface_rho
 
 
